pub enum MidiError {
Transfer(PipeError),
NoInterface,
NoEndpoint,
WrongDirection,
NoPipe,
Descriptor(MidiDescriptorError),
UnsupportedTopology,
InvalidPort,
InvalidMessage(MidiPacketError),
InvalidPacketLength,
}Expand description
USB MIDI host error.
Variants
Transfer(PipeError)
A USB transfer failed.
NoInterface
No MIDIStreaming interface was found.
NoEndpoint
The requested transfer direction is not exposed by the interface.
WrongDirection
An endpoint was opened using the wrong transfer direction.
NoPipe
The controller could not allocate an endpoint pipe.
Descriptor(MidiDescriptorError)
The MIDI descriptors are malformed or exceed a fixed capacity.
UnsupportedTopology
The device uses a topology unsupported by the friendly host API.
InvalidPort
A port does not belong to this MIDI device direction.
InvalidMessage(MidiPacketError)
A MIDI message could not be encoded as an event packet.
InvalidPacketLength
USB-MIDI transfers must contain complete four-byte event packets.